@@ -7,7 +7,7 @@ import unittest, logging
 import colorlog
 
 class TestColoredFormatter (unittest.TestCase):
-	logformat = "%(fg_log)s%(levelname)-8s%(reset)s %(fg_black)s%(name)s%(reset)s %(message)s"
+	logformat = "%(log_color)s%(levelname)-8s%(reset)s %(bold_red)s%(bg_white)s%(name)s%(reset)s %(message)s"
 
 	def setUp(self):
 		formatter = colorlog.ColoredFormatter(self.logformat)
