@@ -28,7 +28,7 @@ colors = [
 ]
 
 # Create foreground and background colors...
-for lcode, lname in [('3', 'fg_'), ('4', 'bg_')]:
+for lcode, lname in [('3', ''), ('4', 'bg_')]:
 	# ...with the list of colors...
 	for code, name in enumerate(colors):
 		code = str(code)
